Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(943)

Unified Diff: remoting/host/ipc_video_frame_capturer.h

Issue 13983010: Use webrtc::DesktopCapturer for screen capturer implementation. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/ipc_desktop_environment_unittest.cc ('k') | remoting/host/ipc_video_frame_capturer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/ipc_video_frame_capturer.h
diff --git a/remoting/host/ipc_video_frame_capturer.h b/remoting/host/ipc_video_frame_capturer.h
index 8d6b90ac231f4479c291d7f1ce9e5ed6d042cff0..48ed750481e43994279511e3fad19ba8725cc2a5 100644
--- a/remoting/host/ipc_video_frame_capturer.h
+++ b/remoting/host/ipc_video_frame_capturer.h
@@ -29,24 +29,32 @@ class IpcVideoFrameCapturer : public media::ScreenCapturer {
scoped_refptr<DesktopSessionProxy> desktop_session_proxy);
virtual ~IpcVideoFrameCapturer();
+ // webrtc::DesktopCapturer interface.
+ virtual void Start(Callback* callback) OVERRIDE;
+ virtual void Capture(const webrtc::DesktopRegion& region) OVERRIDE;
+
// media::ScreenCapturer interface.
- virtual void Start(Delegate* delegate) OVERRIDE;
- virtual void CaptureFrame() OVERRIDE;
+ virtual void SetMouseShapeObserver(
+ MouseShapeObserver* mouse_shape_observer) OVERRIDE;
- // Called when a video frame has been captured. |capture_data| describes
- // a captured frame.
- void OnCaptureCompleted(scoped_refptr<media::ScreenCaptureData> capture_data);
+ // Called when a video |frame| has been captured.
+ void OnCaptureCompleted(scoped_ptr<webrtc::DesktopFrame> frame);
// Called when the cursor shape has changed.
void OnCursorShapeChanged(scoped_ptr<media::MouseCursorShape> cursor_shape);
private:
- // Points to the delegate passed to media::ScreenCapturer::Start().
- media::ScreenCapturer::Delegate* delegate_;
+ // Points to the callback passed to media::ScreenCapturer::Start().
+ media::ScreenCapturer::Callback* callback_;
+
+ MouseShapeObserver* mouse_shape_observer_;
// Wraps the IPC channel to the desktop session agent.
scoped_refptr<DesktopSessionProxy> desktop_session_proxy_;
+ // Set to true when a frame is being captured.
+ bool capture_pending_;
+
// Used to cancel tasks pending on the capturer when it is stopped.
base::WeakPtrFactory<IpcVideoFrameCapturer> weak_factory_;
« no previous file with comments | « remoting/host/ipc_desktop_environment_unittest.cc ('k') | remoting/host/ipc_video_frame_capturer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698